using System;
using System.Collections.Generic;
using System.Text;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class defines constants for some properties.
    /// </summary>
    public static class NamedProperties
    {
        /// <summary>
        /// Security-related properties
        /// </summary>
        public static class Security
        {
            /// <summary>
            /// The binary security descriptor of the item in 
            /// </summary>
            public const string NTSecurityDescriptor = Namespaces.Exchange + "ntsecuritydescriptor";
            /// <summary>
            /// The old property for the binary security descriptor an item
            /// </summary>
            public const string PR_ACL_Table = Namespaces.MapiPropTag + "x3fe0000d";
            /// <summary>
            /// The binary security descriptor of the item in 
            /// </summary>
            public const string PR_NT_Security_Descriptor = Namespaces.MapiPropTag + "x0e270102";
        }

        /// <summary>
        /// Standard DAV properties
        /// </summary>
        public static class Dav
        {
            /// <summary>
            /// The property indicating whether an item is a folder or not
            /// </summary>
            public const string IsFolder = Namespaces.Dav + "isfolder";
        }

        /// <summary>
        /// This class contains names of properties for attachments.
        /// </summary>
        public static class Attachment
        {
            /// <summary>
            /// This property contains the size of the attachment.
            /// </summary>
            public const string Size = Namespaces.MapiPropTag + "x0E210003";
            /// <summary>
            /// This property containt the name of the attachment
            /// </summary>
            public const string LongFilename = Namespaces.HttpMail + "attachmentfilename";
            /// <summary>
            /// This property contains the content-disposition (inline, attachment, etc) of an attachment.
            /// </summary>
            public const string ContentDisposition = Namespaces.MapiPropTag + "x3716001e";
            /// <summary>
            /// This property contains the MIME type of the attachment.
            /// </summary>
            public const string MimeType = Namespaces.MapiPropTag + "x370e001f";
        }
    }
}
