using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;
using System.Collections.ObjectModel;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class contains information about a completed search operation.
    /// </summary>
    public class SearchCompletedEventArgs: AsyncCompletedEventArgs
    {
        private IList<Item> _Items;

        /// <summary>
        /// Returns a collection of <see cref="Item"/>s, returned by the search
        /// operation.
        /// </summary>
        public IList<Item> Items
        {
            get { return _Items; }
        }

        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        /// <param name="cancelled">True, if the operation was cancelled. False, otherwise.</param>
        public SearchCompletedEventArgs(bool cancelled): base(null, cancelled, null)
        {
        }
        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        /// <param name="items">A collection of <see cref="Items"/>s, found
        /// by the search operation.</param>
        public SearchCompletedEventArgs(IList<Item> items)
            : this(false)
        {
            _Items = items;           
        }

        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        /// <param name="error">The exception that occured during the search operation</param>
        public SearchCompletedEventArgs(Exception error)
            : base(error, false, null)
        {
        }

    }
}
