using System;
using System.Collections.Generic;
using System.Text;
using InfiniTec.Threading;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class contains information about a pending search operation.
    /// </summary>
    public class SearchProgress
    {
        
        private RequestStatus _RequestStatus;
        private IList<Item> _Items;
        private Range _Range;

        /// <summary>
        /// Gets or sets the range of the currently retrieved items.
        /// </summary>
        public Range Range
        {
            get { return _Range; }
            set { _Range = value; }
        }
	
        /// <summary>
        /// Provides access to the items retrieved by the search operation.
        /// </summary>
        public IList<Item> Items
        {
            get { return _Items; }
            set { _Items = value; }
        }

        /// <summary>
        /// Returns the status of the current search operation.
        /// </summary>
        [NestedState]
        public RequestStatus RequestStatus
        {
            get { return _RequestStatus; }
            set
            {
                _RequestStatus = value;
                Items = null;
                Range = null;
            }
        }

        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        public SearchProgress()
        {
            _RequestStatus = RequestStatus.Initializing;
        }
    }
}
