using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class contains information about an ongoing search operation.
    /// </summary>
    public class SearchProgressChangedEventArgs : CancelEventArgs
    {
        private IList<Item> _Items;
        private Range _Range;
        private RequestStatus _RequestStatus;

        /// <summary>
        /// Returns the <see cref="RequestStatus"/> of the operation.
        /// </summary>
        public RequestStatus RequestStatus
        {
            get { return _RequestStatus; }
        }

        /// <summary>
        /// Returns the range of the current operation.
        /// </summary>
        public Range Range
        {
            get { return _Range; }
        }

        /// <summary>
        /// Returns a collections of <see cref="Item"/>s.
        /// </summary>
        public IList<Item> Items
        {
            get { return _Items; }
        }

        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        /// <param name="progress">The curren <see cref="SearchProgress"/> of
        /// the search operation.</param>
        /// 
        public SearchProgressChangedEventArgs(SearchProgress progress)
        {
            _Items = progress.Items;
            _Range = progress.Range;
            _RequestStatus = progress.RequestStatus;
        }
    }
}
