using System;
using System.Collections.Generic;
using System.Text;
using System.Security.Principal;

namespace InfiniTec.Exchange.Security
{
    /// <summary>
    /// This class provides access to the security descriptors of items in an 
    /// Exchange store.
    /// </summary>
    public class ItemSecurity: ExchangeSecurity
    {
        /// <summary>
        /// Creates a new instance of this class using the specified settings.
        /// </summary>
        /// <param name="buffer">A buffer containing the binary security descriptor</param>
        /// <param name="offset">The offset where the binary descriptor begins</param>
        public ItemSecurity(byte[] buffer, int offset):
            base(buffer, offset) { }

        /// <summary>
        /// Returns a list of <see cref="ItemAce"/>s which make up the 
        /// Dacl of the item
        /// </summary>
        /// <returns></returns>
        public IList<ItemAce> GetAccessControlEntries()
        {
            return GetAccessControlEntries<ItemAce>();
        }

        /// <summary>
        /// Sets the specified access mask for the identity.
        /// </summary>
        /// <param name="identity">A <see cref="SecurityIdentifier" /> instance</param>
        /// <param name="accessMask">The desired access mask</param>
        public void DangerousSetAccess(SecurityIdentifier identity, ItemAccessMasks accessMask)
        {
            ItemAce ace;

            if (!TryGetAce(identity, out ace))
            {
                ace = AddAce(identity);
            }
            ace.DangerousSetAccess(accessMask);
        }
    }
}
