using System;
using System.Collections.Generic;
using System.Text;
using System.Xml.XPath;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// Represents a single-valued property of an Exchange <see cref="Item"/>
    /// </summary>
    /// <typeparam name="T">The type of the property</typeparam>
    public class Property<T>: Property
    {
        private T _Value;

        /// <summary>
        /// Gets or sets the value of the item
        /// </summary>
        public T Value
        {
            get { return _Value; }
            set { _Value = value; SetChanged();  }
        }

        /// <summary>
        /// Loads the value of the property from the navigator
        /// </summary>
        /// <param name="navigator">A <see cref="XPathNavigator"/> containing the
        /// value.</param>
        internal sealed override void Load(XPathNavigator navigator)
        {
            Value = DecodeValue<T>(navigator.InnerXml);
        }

        /// <summary>
        /// Creates a new instance of this class using the specified namespace and local
        /// name.
        /// </summary>
        /// <param name="ns">The namespace of the property</param>
        /// <param name="localName">The local name of the property</param>
        public Property(string ns, string localName): base(ns, localName)
        {

        }

        /// <summary>
        /// Creates a new instance of this class using the specified namespace and local
        /// name.
        /// </summary>
        /// <param name="fullQualifiedName">The full qualified name of the property</param>
        /// <param name="value">The value of the property</param>
        public Property(string fullQualifiedName, T value): this(fullQualifiedName)
        {
            Value = value;
            SetChanged();
        }

        /// <summary>
        /// Creates a new instance of this class using the specified namespace and local
        /// name.
        /// </summary>
        /// <param name="ns">The namespace of the property</param>
        /// <param name="localName">The local name of the property</param>
        /// <param name="value">The value of the property</param>
        public Property(string ns, string localName, T value): this(ns, localName)
        {
            Value = value;
            SetChanged();
        }
        /// <summary>
        /// Creates a new instance of this class using the specified namespace and local
        /// name.
        /// </summary>
        /// <param name="fullQualifiedName">The full qualified name of the property</param>
        public Property(string fullQualifiedName): base(fullQualifiedName)
        {

        }

        internal sealed override void SaveTo(System.Xml.XmlWriter writer)
        {
            writer.WriteStartElement(Name, Namespace);
            
            writer.WriteAttributeString("dt", Namespaces.DataType, GetDataType<T>());
            writer.WriteString(EncodeValue<T>(Value));

            writer.WriteEndElement();
        }

     
    }
}
